@@ -118,6 +118,7 @@ def make_arg_kwargs(arg_def):
     nargs = get_document_property(arg_def, "nargs")
     action = get_document_property(arg_def, "action")
     value_type = get_document_property(arg_def, "valueType")
+    required = get_document_property(arg_def, "required")
 
     if nargs is not None:
         if nargs == 0:
@@ -131,6 +132,9 @@ def make_arg_kwargs(arg_def):
     if value_type is not None:
         kwargs["type"] = value_type
 
+    if required is not None:
+        kwargs["required"] = required
+
     default = get_document_property(arg_def, "default")
 
     kwargs["default"] = default
@@ -224,7 +228,6 @@ class DargeParser(ArgumentParser):
             msg =  ("unrecognized arguments: %s" % argv_str +
                     "\n" + self.get_errored_parser().get_usage() +
                     "\n" + details_msg)
-
             self.error(msg)
 
         # add additional information
@@ -483,10 +486,12 @@ def get_document_property(document, name, default=None):
 ###############################################################################
 def resolve_function(full_func_name):
     names = full_func_name.split(".")
-    module_name = names[0]
-    module_obj = sys.modules[module_name]
+    module_name = ".".join(names[:-1])
+    module_obj = __import__(module_name)
+
     result = module_obj
     for name in names[1:]:
         result = getattr(result, name)
 
     return result
+
